@@ -198,7 +198,7 @@ class OverrideStudent(Base):
     assignment = relationship('Assignment')
     override_id = Column('assignment_override_id', ForeignKey('assignment_overrides.id'))
     override = relationship('Override')
-    user_id = Colunm(ForeignKey('users.id'))
+    user_id = Column(ForeignKey('users.id'))
     user = relationship('User')
     quiz_id = Column(ForeignKey('quizzes.id'))
     quiz = relationship('Quiz')
@@ -279,6 +279,8 @@ class Enrollment(Base):
     course_section_id = Column(ForeignKey('course_sections.id'))
     course_section = relationship('CourseSection')
     workflow_state = Column(String(255))
+    sis_pseudonym_id = Column(ForeignKey('pseudonyms.id'))
+    sis_pseudonym = relationship('Pseudonym')
 
     def __repr__(self):
         return '<Enrollment {} (id={})>'.format(self, self.id)
